/*

 ============================================================================
                   The Apache Software License, Version 1.1
 ============================================================================
 
 Copyright (C) @year@ The Apache Software Foundation. All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modifica-
 tion, are permitted provided that the following conditions are met:
 
 1. Redistributions of  source code must  retain the above copyright  notice,
    this list of conditions and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright notice,
    this list of conditions and the following disclaimer in the documentation
    and/or other materials provided with the distribution.
 
 3. The end-user documentation included with the redistribution, if any, must
    include  the following  acknowledgment:  "This product includes  software
    developed  by the  Apache Software Foundation  (http://www.apache.org/)."
    Alternately, this  acknowledgment may  appear in the software itself,  if
    and wherever such third-party acknowledgments normally appear.
 
 4. The names "Jakarta", "Apache Avalon", "Avalon Excalibur", "Avalon
    Framework" and "Apache Software Foundation"  must not be used to endorse
    or promote products derived  from this  software without  prior written
    permission. For written permission, please contact apache@apache.org.
 
 5. Products  derived from this software may not  be called "Apache", nor may
    "Apache" appear  in their name,  without prior written permission  of the
    Apache Software Foundation.
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
 INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
 APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
 INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
 DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
 OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
 ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
 (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 This software  consists of voluntary contributions made  by many individuals
 on  behalf of the Apache Software  Foundation and was  originally created by
 Stefano Mazzocchi  <stefano@apache.org>. For more  information on the Apache 
 Software Foundation, please see <http://www.apache.org/>.
 
*/
package org.apache.avalon.framework.resolver;

import org.apache.avalon.framework.context.Context;

/**
 * A <code>Query</code> will identify all the objects needed for a specific lookup.
 * The <code>Query</code> will help the resolver obtain reference to the necessary
 * objects in order.  In other words, if we asked for three objects, the order of
 * the objects returned by the <code>Resolver</code> will match the order that the
 * keys were added to the <code>Query</code> object.
 *
 * @author <a href="mailto:bloritsch@apache.org">Berin Loritsch</a>
 */
public interface Query
{

    /**
     * Add a lookup key.  The Lookup key consists of a psuedo protocol, and the key
     * value.  That way, we can ensure that the object you get is the proper type.
     * The required psuedo protocols include "component", "service", and "object".
     *
     * <p>Example:</p>
     * <pre>
     *   query.addKey( "component:org.apache.avalon.excalibur.datasource.DataSourceComponent" );
     *   query.addKey( "service:org.apache.avalon.cornerstone.services.ConnectionManager" );
     *   query.addKey( "object:foo-object" );
     * </pre>
     */
    void addKey( String value );

    /**
     * Remove a lookup key.  This facilitates a quick test/resolve approach.  The
     * <code>Query</code> object can be initialized in the constructor complete with
     * references to optional components.  Your code can then call
     * <code>hasReferences</code> and remove any optional keys from the Query that the
     * <code>Resolver</code> cannot handle.
     */
    void removeKey( String value );

    /**
     * You can add further hints, or attributes to the query that can help the
     * <code>Resolver</code> get the specific instance you want.  It is important
     * to note that the attributes do apply to all the key values.  The
     * <code>Resolver</code> does have the right to ignore any or all of the
     * attributes if it wants.
     */
    void addAttribute( String name, Object value );

    /**
     * You can remove hints, or attributes to the query that can help the
     * <code>Resolver</code> get the specific instance you want.
     */
    void removeAttribute( String name );

    /**
     * This obtains a reference to the attribute context used by the
     * code>Resolver</code>.  The context uses resolveable entryies to determine
     * the keys, and what types they are.
     */
    Context queryContext();
}
